@@ -18,6 +18,9 @@
 */
 
 #include "ruleserver.h"
+#include "services.h"
+#include "smsgateway.h"
+
 
 RuleServer* RuleServer::instance_m;
 
@@ -55,9 +58,9 @@ void RuleServer::exportXml(ticpp::Element* pConfig)
   std::list<Rule*>::iterator it;
   for (it = rulesList_m.begin(); it != rulesList_m.end(); it++)
   {
-    ticpp::Element* pElem = new ticpp::Element("rule");
-    (*it)->exportXml(pElem);
-    pConfig->LinkEndChild(pElem);
+    ticpp::Element pElem("rule");
+    (*it)->exportXml(&pElem);
+    pConfig->LinkEndChild(&pElem);
   }
 }
 
@@ -116,35 +119,35 @@ void Rule::exportXml(ticpp::Element* pConfig)
         pConfig->SetAttribute("active", "no");
     if (condition_m)
     {
-        ticpp::Element* pCond = new ticpp::Element("condition");
-        condition_m->exportXml(pCond);
-        pConfig->LinkEndChild(pCond);
+        ticpp::Element pCond("condition");
+        condition_m->exportXml(&pCond);
+        pConfig->LinkEndChild(&pCond);
     }
 
     ActionsList_t::iterator it;
     if (actionsList_m.begin() != actionsList_m.end())
     {
-        ticpp::Element* pList = new ticpp::Element("actionlist");
-        pConfig->LinkEndChild(pList);
+        ticpp::Element pList("actionlist");
+        pConfig->LinkEndChild(&pList);
     
         for(it=actionsList_m.begin(); it != actionsList_m.end(); ++it)
         {
-            ticpp::Element* pElem = new ticpp::Element("action");
-            (*it)->exportXml(pElem);
-            pList->LinkEndChild(pElem);
+            ticpp::Element pElem("action");
+            (*it)->exportXml(&pElem);
+            pList.LinkEndChild(&pElem);
         }
     }
     if (actionsListFalse_m.begin() != actionsListFalse_m.end())
     {
-        ticpp::Element* pList = new ticpp::Element("actionlist");
-        pList->SetAttribute("type", "on-false");
-        pConfig->LinkEndChild(pList);
+        ticpp::Element pList("actionlist");
+        pList.SetAttribute("type", "on-false");
+        pConfig->LinkEndChild(&pList);
     
         for(it=actionsListFalse_m.begin(); it != actionsListFalse_m.end(); ++it)
         {
-            ticpp::Element* pElem = new ticpp::Element("action");
-            (*it)->exportXml(pElem);
-            pList->LinkEndChild(pElem);
+            ticpp::Element pElem("action");
+            (*it)->exportXml(&pElem);
+            pList.LinkEndChild(&pElem);
         }
     }
 }
@@ -344,38 +347,12 @@ void SendSmsAction::exportXml(ticpp::Element* pConfig)
     Action::exportXml(pConfig);
 }
 
-#include <curl/curl.h>
-
 void SendSmsAction::Run (pth_sem_t * stop)
 {
     pth_sleep(delay_m);
     std::cout << "Execute SendSmsAction with value " << value_m << std::endl;
 
-    CURL *curl;
-    CURLcode res;
- 
-    curl = curl_easy_init();
-    if(curl) {
-				std::stringstream msg;
-//				msg << "http://api.clickatell.com/http/sendmsg?user=jfmeessen&password=eja774&api_id=2952317&to="
-//            << id_m << "&text=" << value_m;
-				msg << "http://192.168.0.10:4001/index.php?action=" << value_m << "&gad=" << id_m; //&to="
-        std::string url = msg.str();
-//        curl_easy_setopt(curl, CURLOPT_VERBOSE, TRUE);
-        curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
-//        curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, 1);
-         
-        res = curl_easy_perform(curl);
-
-        std::cout << "curl_easy_perform returned: " << res ;
-        if (res != 0)
-            std::cout << "; msg=" << curl_easy_strerror(res);
-        std::cout << std::endl;
-
-        curl_easy_cleanup(curl);
-    }
-    else
-        std::cout << "Unable to execute SendSmsAction. Curl not available" << std::endl;
+    Services::instance()->getSmsGateway()->sendSms(id_m, value_m);
 }
 
 
@@ -446,9 +423,9 @@ void AndCondition::exportXml(ticpp::Element* pConfig)
   ConditionsList_t::iterator it;
   for (it = conditionsList_m.begin(); it != conditionsList_m.end(); it++)
   {
-    ticpp::Element* pElem = new ticpp::Element("condition");
-    (*it)->exportXml(pElem);
-    pConfig->LinkEndChild(pElem);
+    ticpp::Element pElem("condition");
+    (*it)->exportXml(&pElem);
+    pConfig->LinkEndChild(&pElem);
   }
 }
   
@@ -488,9 +465,9 @@ void OrCondition::exportXml(ticpp::Element* pConfig)
   ConditionsList_t::iterator it;
   for (it = conditionsList_m.begin(); it != conditionsList_m.end(); it++)
   {
-    ticpp::Element* pElem = new ticpp::Element("condition");
-    (*it)->exportXml(pElem);
-    pConfig->LinkEndChild(pElem);
+    ticpp::Element pElem("condition");
+    (*it)->exportXml(&pElem);
+    pConfig->LinkEndChild(&pElem);
   }
 }
   
@@ -519,9 +496,9 @@ void NotCondition::exportXml(ticpp::Element* pConfig)
   pConfig->SetAttribute("type", "not");
   if (condition_m)
   {
-    ticpp::Element* pElem = new ticpp::Element("condition");
-    condition_m->exportXml(pElem);
-    pConfig->LinkEndChild(pElem);
+    ticpp::Element pElem("condition");
+    condition_m->exportXml(&pElem);
+    pConfig->LinkEndChild(&pElem);
   }
 }
   
@@ -535,8 +512,13 @@ ObjectCondition::~ObjectCondition()
 
 bool ObjectCondition::evaluate()
 {
-    bool val = object_m->getIntValue() == value_m;
-    std::cout << "ObjectCondition evaluated as '" << val << "' value_m='" << value_m << "' getIntValue='" << object_m->getIntValue() << "'" << std::endl;
+    int value = object_m->getIntValue();
+    bool val = value == value_m;
+    std::cout << "ObjectCondition (id='" << object_m->getID()
+              << "') evaluated as '" << val
+              << "' value_m='" << value_m
+              << "' getIntValue='" << value
+              << "'" << std::endl;
     return val;
 }
 
@@ -579,7 +561,8 @@ void ObjectCondition::importXml(ticpp::Element* pConfig)
             throw ticpp::Exception(msg.str());
         }
     }
-    std::cout << "ObjectCondition: configured value_m='" << value_m << "' (rdstate=" << (int)val.rdstate() << "; bad=" << val.bad() << "; good="<< val.good() << ")"<< std::endl;
+    std::cout << "ObjectCondition: configured value_m='" << value_m << "'" << std::endl;
+//    std::cout <<"(rdstate=" << (int)val.rdstate() << "; bad=" << val.bad() << "; good="<< val.good() << ")"<< std::endl;
 }
 
 void ObjectCondition::exportXml(ticpp::Element* pConfig)
@@ -643,21 +626,21 @@ void TimerCondition::exportXml(ticpp::Element* pConfig)
     if (trigger_m)
         pConfig->SetAttribute("trigger", "true");
 
-    ticpp::Element* pAt = new ticpp::Element("at");
-    at_m.exportXml(pAt);
-    pConfig->LinkEndChild(pAt);
+    ticpp::Element pAt("at");
+    at_m.exportXml(&pAt);
+    pConfig->LinkEndChild(&pAt);
     
     if (during_m == -1)
     {
-        ticpp::Element* pUntil = new ticpp::Element("until");
-        until_m.exportXml(pUntil);
-        pConfig->LinkEndChild(pUntil);
+        ticpp::Element pUntil("until");
+        until_m.exportXml(&pUntil);
+        pConfig->LinkEndChild(&pUntil);
     }
     else if (during_m != 0)
     {
-        ticpp::Element* pDuring = new ticpp::Element("during");
-        pDuring->SetText(during_m);
-        pConfig->LinkEndChild(pDuring);
+        ticpp::Element pDuring("during");
+        pDuring.SetText(during_m);
+        pConfig->LinkEndChild(&pDuring);
     }
 }
   
