@@ -18,11 +18,10 @@
 */
 
 #include "timermanager.h"
+#include "services.h"
 #include <iostream>
 #include <ctime>
 
-TimerManager* TimerManager::instance_m;
-
 TimerManager::TimerManager()
 {
 }
@@ -32,13 +31,6 @@ TimerManager::~TimerManager()
   StopDelete ();
 }
 
-TimerManager* TimerManager::instance()
-{
-  if (instance_m == 0)
-    instance_m = new TimerManager();
-  return instance_m;
-}
-
 void TimerManager::Run (pth_sem_t * stop1)
 {
   pth_event_t stop = pth_event (PTH_EVENT_SEM, stop1);
@@ -224,7 +216,7 @@ void PeriodicTask::reschedule(time_t now)
 									<< timeinfo->tm_hour << ":"
 									<< timeinfo->tm_min << ":0 ("
 									<< nextExecTime_m << ")" << std::endl;
-				TimerManager::instance()->addTask(this);
+				Services::instance()->getTimerManager()->addTask(this);
     }
     else
         std::cout << "PeriodicTask: not rescheduled" << std::endl;
@@ -292,8 +284,13 @@ time_t PeriodicTask::findNext(time_t start, TimeSpec* next)
 
 		timeinfo->tm_sec = 0;
 		time_t nextExecTime = mktime(timeinfo);
+		if (nextExecTime < 0)
+		{
+				std::cout << "PeriodicTask: no more schedule available" << std::endl;
+				return 0;
+		}
 		if (next->exception_m != TimeSpec::DontCare) {
-				bool exception = ExceptionDays::instance()->isException(nextExecTime);
+				bool exception = Services::instance()->getExceptionDays()->isException(nextExecTime);
 				if (exception && next->exception_m == TimeSpec::No || !exception && next->exception_m == TimeSpec::Yes) {
 						std::cout << "PeriodicTask: calling findNext recursively! (" << nextExecTime << ")" << std::endl;
 						return findNext(nextExecTime, next);
@@ -328,7 +325,6 @@ void DaySpec::exportXml(ticpp::Element* pConfig)
         pConfig->SetAttribute("year", year_m+1900);
 }
 
-ExceptionDays* ExceptionDays::instance_m;
 
 ExceptionDays::ExceptionDays()
 {
@@ -342,13 +338,6 @@ ExceptionDays::~ExceptionDays()
     delete (*it);
 }
 
-ExceptionDays* ExceptionDays::instance()
-{
-  if (instance_m == 0)
-    instance_m = new ExceptionDays();
-  return instance_m;
-}
-
 void ExceptionDays::importXml(ticpp::Element* pConfig)
 {
   ticpp::Iterator< ticpp::Element > child;
@@ -372,9 +361,9 @@ void ExceptionDays::exportXml(ticpp::Element* pConfig)
   DaysList_t::iterator it;
   for (it = daysList_m.begin(); it != daysList_m.end(); it++)
   {
-    ticpp::Element* pElem = new ticpp::Element("date");
-    (*it)->exportXml(pElem);
-    pConfig->LinkEndChild(pElem);
+    ticpp::Element pElem("date");
+    (*it)->exportXml(&pElem);
+    pConfig->LinkEndChild(&pElem);
   }
 }
 
